## Hypothesis Creation

To address this question we have assembled the following team:

{team_description}

Based on the team composition, along with all identified known and unknown facts, please begin with one to three hypotheses that could be tested to address the original request.

For each hypothesis, please provide the following:

1. A description of the hypothesis.
2. A description of how the hypothesis could be verified or disproven.
3. The team members who are required to verify or disprove the hypothesis.

Note that not all team members are necessarily required for each hypothesis; use your judgment to determine which team members are needed.

